@@ -191,6 +191,7 @@ symbols! {
         Borrow,
         BorrowMut,
         Break,
+        BuildHasher,
         C,
         CStr,
         C_dash_unwind: "C-unwind",
@@ -372,6 +373,7 @@ symbols! {
         ToString,
         TokenStream,
         Trait,
+        TrivialClone,
         Try,
         TryCaptureGeneric,
         TryCapturePrintable,
@@ -400,6 +402,7 @@ symbols! {
         _t,
         _task_context,
         a32,
+        aarch64,
         aarch64_target_feature,
         aarch64_unstable_target_feature,
         aarch64_ver_target_feature,
@@ -449,6 +452,7 @@ symbols! {
         altivec,
         alu32,
         always,
+        amdgpu,
         analysis,
         and,
         and_then,
@@ -466,6 +470,7 @@ symbols! {
         args,
         arith_offset,
         arm,
+        arm64ec,
         arm_target_feature,
         array,
         as_dash_needed: "as-needed",
@@ -517,6 +522,7 @@ symbols! {
         async_fn_track_caller,
         async_fn_traits,
         async_for_loop,
+        async_gen_internals,
         async_iterator,
         async_iterator_poll_next,
         async_trait_bounds,
@@ -554,6 +560,7 @@ symbols! {
         autodiff_reverse,
         automatically_derived,
         available_externally,
+        avr,
         avx,
         avx10_target_feature,
         avx512_target_feature,
@@ -578,6 +585,7 @@ symbols! {
         bitxor_assign,
         black_box,
         block,
+        blocking,
         bool,
         bool_then,
         borrowck_graphviz_format,
@@ -586,6 +594,7 @@ symbols! {
         box_patterns,
         box_syntax,
         boxed_slice,
+        bpf,
         bpf_target_feature,
         braced_empty_structs,
         branch,
@@ -604,12 +613,14 @@ symbols! {
         c_str_literals,
         c_unwind,
         c_variadic,
+        c_variadic_naked_functions,
         c_void,
         call,
         call_mut,
         call_once,
         call_once_future,
         call_ref_future,
+        caller,
         caller_location,
         capture_disjoint_fields,
         carrying_mul_add,
@@ -624,7 +635,7 @@ symbols! {
         cfg_accessible,
         cfg_attr,
         cfg_attr_multi,
-        cfg_attr_trace: "<cfg_attr>", // must not be a valid identifier
+        cfg_attr_trace: "<cfg_attr_trace>", // must not be a valid identifier
         cfg_boolean_literals,
         cfg_contract_checks,
         cfg_doctest,
@@ -645,7 +656,7 @@ symbols! {
         cfg_target_has_reliable_f16_f128,
         cfg_target_thread_local,
         cfg_target_vendor,
-        cfg_trace: "<cfg>", // must not be a valid identifier
+        cfg_trace: "<cfg_trace>", // must not be a valid identifier
         cfg_ub_checks,
         cfg_version,
         cfi,
@@ -694,7 +705,9 @@ symbols! {
         compile_error,
         compiler,
         compiler_builtins,
+        compiler_copy,
         compiler_fence,
+        compiler_move,
         concat,
         concat_bytes,
         concat_idents,
@@ -740,7 +753,6 @@ symbols! {
         const_raw_ptr_to_usize_cast,
         const_refs_to_cell,
         const_refs_to_static,
-        const_trait,
         const_trait_bound_opt_out,
         const_trait_impl,
         const_try,
@@ -790,6 +802,7 @@ symbols! {
         crate_type,
         crate_visibility_modifier,
         crt_dash_static: "crt-static",
+        csky,
         csky_target_feature,
         cstr_type,
         cstring_as_c_str,
@@ -865,6 +878,7 @@ symbols! {
         destructuring_assignment,
         diagnostic,
         diagnostic_namespace,
+        diagnostic_on_const,
         dialect,
         direct,
         discriminant_kind,
@@ -888,7 +902,6 @@ symbols! {
         doc_primitive,
         doc_spotlight,
         doctest,
-        document_private_items,
         dotdot: "..",
         dotdot_in_tuple_patterns,
         dotdoteq_in_patterns,
@@ -1085,10 +1098,7 @@ symbols! {
         format_args_nl,
         format_argument,
         format_arguments,
-        format_count,
         format_macro,
-        format_placeholder,
-        format_unsafe_arg,
         framework,
         freeze,
         freeze_impls,
@@ -1103,7 +1113,9 @@ symbols! {
         from_output,
         from_residual,
         from_size_align_unchecked,
+        from_str,
         from_str_method,
+        from_str_nonconst,
         from_u16,
         from_usize,
         from_yeet,
@@ -1156,6 +1168,7 @@ symbols! {
         hashset_drain_ty,
         hashset_iter,
         hashset_iter_ty,
+        hexagon,
         hexagon_target_feature,
         hidden,
         hide,
@@ -1248,6 +1261,7 @@ symbols! {
         into_async_iter_into_iter,
         into_future,
         into_iter,
+        into_try_type,
         intra_doc_pointers,
         intrinsics,
         intrinsics_unaligned_volatile_load,
@@ -1342,11 +1356,14 @@ symbols! {
         logf32,
         logf64,
         logf128,
+        loongarch32,
+        loongarch64,
         loongarch_target_feature,
         loop_break_value,
         loop_match,
         lr,
         lt,
+        m68k,
         m68k_target_feature,
         macro_at_most_once_rep,
         macro_attr,
@@ -1387,11 +1404,13 @@ symbols! {
         maybe_uninit,
         maybe_uninit_uninit,
         maybe_uninit_zeroed,
+        mem_align_const,
         mem_align_of,
         mem_discriminant,
         mem_drop,
         mem_forget,
         mem_replace,
+        mem_size_const,
         mem_size_of,
         mem_size_of_val,
         mem_swap,
@@ -1420,6 +1439,10 @@ symbols! {
         minnumf32,
         minnumf64,
         minnumf128,
+        mips,
+        mips32r6,
+        mips64,
+        mips64r6,
         mips_target_feature,
         mir_assume,
         mir_basic_block,
@@ -1468,6 +1491,7 @@ symbols! {
         move_ref_pattern,
         move_size_limit,
         movrs_target_feature,
+        msp430,
         mul,
         mul_assign,
         mul_with_overflow,
@@ -1543,6 +1567,7 @@ symbols! {
         non_exhaustive_omitted_patterns_lint,
         non_lifetime_binders,
         non_modrs_mods,
+        nonblocking,
         none,
         nontemporal_store,
         noop_method_borrow,
@@ -1555,10 +1580,12 @@ symbols! {
         notable_trait,
         note,
         null,
+        nvptx64,
         nvptx_target_feature,
         object_safe_for_dispatch,
         of,
         off,
+        offload,
         offset,
         offset_of,
         offset_of_enum,
@@ -1568,6 +1595,7 @@ symbols! {
         old_name,
         omit_gdb_pretty_printer_section,
         on,
+        on_const,
         on_unimplemented,
         opaque,
         opaque_module_name_placeholder: "<opaque>",
@@ -1665,6 +1693,7 @@ symbols! {
         pin,
         pin_ergonomics,
         pin_macro,
+        pin_v2,
         platform_intrinsics,
         plugin,
         plugin_registrar,
@@ -1679,6 +1708,9 @@ symbols! {
         post_cleanup: "post-cleanup",
         post_dash_lto: "post-lto",
         postfix_match,
+        powerpc,
+        powerpc64,
+        powerpc64le,
         powerpc_target_feature,
         powf16,
         powf32,
@@ -1778,6 +1810,7 @@ symbols! {
         read_via_copy,
         readonly,
         realloc,
+        realtime,
         reason,
         reborrow,
         receiver,
@@ -1826,6 +1859,8 @@ symbols! {
         resume,
         return_position_impl_trait_in_trait,
         return_type_notation,
+        riscv32,
+        riscv64,
         riscv_target_feature,
         rlib,
         ropi,
@@ -1934,12 +1969,14 @@ symbols! {
         rustc_objc_class,
         rustc_objc_selector,
         rustc_object_lifetime_default,
+        rustc_offload_kernel,
         rustc_on_unimplemented,
         rustc_outlives,
         rustc_paren_sugar,
         rustc_partition_codegened,
         rustc_partition_reused,
         rustc_pass_by_value,
+        rustc_pass_indirectly_in_non_rustic_abis,
         rustc_peek,
         rustc_peek_liveness,
         rustc_peek_maybe_init,
@@ -1953,6 +1990,7 @@ symbols! {
         rustc_regions,
         rustc_reservation_impl,
         rustc_serialize,
+        rustc_should_not_be_called_on_const_items,
         rustc_simd_monomorphize_lane_limit,
         rustc_skip_during_method_dispatch,
         rustc_specialization_trait,
@@ -1972,7 +2010,9 @@ symbols! {
         rvalue_static_promotion,
         rwpi,
         s,
+        s390x,
         s390x_target_feature,
+        s390x_target_feature_vector,
         safety,
         sanitize,
         sanitizer_cfi_generalize_pointers,
@@ -2100,9 +2140,13 @@ symbols! {
         slice_patterns,
         slicing_syntax,
         soft,
+        sparc,
+        sparc64,
         sparc_target_feature,
+        spe_acc,
         specialization,
         speed,
+        spirv,
         spotlight,
         sqrtf16,
         sqrtf32,
@@ -2233,6 +2277,7 @@ symbols! {
         transparent_enums,
         transparent_unions,
         trivial_bounds,
+        trivial_clone,
         truncf16,
         truncf32,
         truncf64,
@@ -2243,6 +2288,8 @@ symbols! {
         try_from_fn,
         try_into,
         try_trait_v2,
+        try_trait_v2_residual,
+        try_update,
         tt,
         tuple,
         tuple_indexing,
@@ -2360,6 +2407,7 @@ symbols! {
         unwrap,
         unwrap_binder,
         unwrap_or,
+        update,
         use_cloned,
         use_extern_macros,
         use_nested_groups,
@@ -2417,6 +2465,8 @@ symbols! {
         vtable_size,
         warn,
         wasip2,
+        wasm32,
+        wasm64,
         wasm_abi,
         wasm_import_module,
         wasm_target_feature,
@@ -2443,12 +2493,15 @@ symbols! {
         write_str,
         write_via_move,
         writeln_macro,
+        x86,
+        x86_64,
         x86_amx_intrinsics,
         x87_reg,
         x87_target_feature,
         xer,
         xmm_reg,
         xop_target_feature,
+        xtensa,
         yeet_desugar_details,
         yeet_expr,
         yes,
